/*
 * COPYRIGHT INFORMATION - DO NOT REMOVE
 *
 * Copyright (c) LinuxMagic Inc. 2016 All Rights Reserved
 *
 * This file contains Original Code as created by LinuxMagic Inc.
 *
 * The Original Code is distributed on an 'AS IS' basis,
 * WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESS OR IMPLIED, AND LINUXMAGIC
 * HEREBY DISCLAIMS ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET
 * ENJOYMENT OR NON-INFRINGEMENT.
 *
 * Do NOT download, distribute, use or alter this software or file in any
 * way without express written permission from LinuxMagic Inc. or its parent
 * company Wizard Tower TechnoServices signed by an authorized company officer.
 *
 * Author(s): Rares Harnagea <rares@linuxmagic.com>
 *
 * $Id$
 */
"use strict";

if (!AT) {
    var AT = {};
}

//! helper function that will show an error message to the screen
/*!
 * @params string message the error message that we want to display
 *
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
AT.showError = function(message) {
    adtrack_hideConfirmBox();
    if (message === undefined) {
        return;
    }

    var $ = jQuery;
    var targetDiv = $('#adtrack-message');
    if (targetDiv.length === 0) {
        var p = $('<p>').addClass('error').text(message);
        targetDiv.empty().append(p);
    }
};

//! helper function that will show the confirmation box and overlay
/*!
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
AT.showConfirmBox = function() {
    var $ = jQuery;
    var overlay = $('#adtrack_confirmOverlay');
    var box = $('#adtrack_confirmBox');
    if (overlay.length === 0 || box.length === 0) {
        return;
    }
    overlay.show();
    box.show();
};

//! helper function that will hide the confirmation box and overlay
/*!
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
AT.hideConfirmBox = function(event) {
    var $ = jQuery;
    var overlay = $('#adtrack_confirmOverlay');
    var box = $('#adtrack_confirmBox');
    if (event !== undefined && typeof event === 'object') {
        if ($(event.target).closest('#adtrack_confirmBox').length > 0) {
            return;
        }
    }
    if (overlay.length === 0 || box.length === 0) {
        return;
    }
    overlay.hide();
    box.hide();
};

//! helper function that will clone the contentn of a comtainer DOM element into the confirm box
/*!
 * @params string domId the ID of the container
 *
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
AT.showBox = function(domId) {
    if (domId === undefined || typeof domId !== 'string') {
        return;
    }

    var $ = jQuery;
    var domEl = $('#' + domId);
    if (domEl.length === 0) {
        return;
    }
    var box = $('#adtrack_confirmBox');
    if (box.length === 0) {
        return;
    }
    box.empty().empty().html(domEl.clone().show());
    AT.showConfirmBox();
};

//! helper function that will show a section by providing the ID
/*!
 * @params string domId the ID of the container
 *         object event the target event
 *
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
AT.showSection = function(domId, event) {
    if (domId === undefined || typeof domId !== 'string') {
        return;
    }

    var $ = jQuery;
    var domEl = $('#' + domId);
    if (domEl.length === 0) {
        return;
    }
    $('.tab-content').hide()
    domEl.show();
    if (event !== undefined && typeof event === 'object') {
        $('.nav.nav-tabs li').removeClass('active');
        $(event.target).parent().addClass('active');
        // clear the messages
        $('#adtrack-message').empty();
    }

    if (location.hash) {
        setTimeout(function() {
            window.scrollTo(0, 0);
        }, 1);
    }
};

//! Main function that will run when the document is ready
/*!
 *
 * @return void
 *
 * @author Rares Harnagea <rares@linuxmagic.com>
 */
jQuery(document).ready(function() {

    var $ = jQuery;

    // fix the tab and show the correct tab or reloading
    var tab = $(location).attr('hash');
    if (tab === undefined || tab === null || tab === '') {
        tab = 'adtrack-dashboard';
    } else {
        tab = tab.substr(tab.indexOf("#") + 1);

        $('.nav.nav-tabs li').removeClass('active');
        $('.nav-tabs li[data-section="' + tab + '"]').addClass('active');
    }
    // show the section
    AT.showSection(tab);
    // If the is a hash on URL scroll top
    if (location.hash) {
        setTimeout(function() {
            window.scrollTo(0, 0);
        }, 1);
    }

});


